##  Adding Fact Sheets as Shapes
In order to include fact sheets from the Inventory in your diagrams, do the following:
  1. Click on "+" icon in the toolbar. (alternatively, you can also right-click anywhere on the canvas and choose Insert from Inventory).
  2. A window will open showing all the fact sheets from the Inventory. Make use of filters to choose the fact sheets needed, either individually by using the check box to the left and clicking Insert selected or by choosing a specific fact sheet type through the filter and then clicking Insert all.
  3. Selected fact sheets are now presented in the canvas. You can easily adjust their styling, position, and alignment by selecting and moving them around.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27436e3c7a44101496a4be723ed2690e_LowRes.gif)
